#source: attr-gnu-4-0.s
#source: attr-gnu-4-0.s
#ld: -r
#readelf: -A

MIPS ABI Flags Version: 0

ISA: MIPS.*
GPR size: .*
CPR1 size: .*
CPR2 size: 0
FP ABI: Hard or soft float
ISA Extension: .*
ASEs:
	None
FLAGS 1: 0000000.
FLAGS 2: 00000000
