// thin_archive_main.cc -- a test case for gold

// Copyright (C) 2008-2023 Free Software Foundation, Inc.
// Written by Cary Coutant <ccoutant@google.com>.

// This file is part of gold.

// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
// MA 02110-1301, USA.

// This is the main program for the thin archive tests. It calls a single
// routine, t1, defined in libthin1.a or libthin3.a, which then references
// other routines in the same and other libraries, to make sure that all
// archive members are linked properly.

#include <cassert>

extern int t1();

// Main function.  Call the test function.

int
main()
{
  assert(t1() == 0x4321);
  return 0;
}
