#objdump: -dr

.*


Disassembly of section \.text:

0+ <\.text>:
[^:]*:	d53803a0 	mrs	x0, id_dfr1_el1
[^:]*:	d53803c0 	mrs	x0, id_mmfr5_el1
[^:]*:	d53802e0 	mrs	x0, id_isar6_el1
[^:]*:	d5384602 	mrs	x2, icc_pmr_el1
[^:]*:	d5184603 	msr	icc_pmr_el1, x3
[^:]*:	d538c800 	mrs	x0, icc_iar0_el1
[^:]*:	d518c821 	msr	icc_eoir0_el1, x1
[^:]*:	d538c840 	mrs	x0, icc_hppir0_el1
[^:]*:	d538c862 	mrs	x2, icc_bpr0_el1
[^:]*:	d518c863 	msr	icc_bpr0_el1, x3
[^:]*:	d538c882 	mrs	x2, icc_ap0r0_el1
[^:]*:	d518c883 	msr	icc_ap0r0_el1, x3
[^:]*:	d538c8a2 	mrs	x2, icc_ap0r1_el1
[^:]*:	d518c8a3 	msr	icc_ap0r1_el1, x3
[^:]*:	d538c8c2 	mrs	x2, icc_ap0r2_el1
[^:]*:	d518c8c3 	msr	icc_ap0r2_el1, x3
[^:]*:	d538c8e2 	mrs	x2, icc_ap0r3_el1
[^:]*:	d518c8e3 	msr	icc_ap0r3_el1, x3
[^:]*:	d538c902 	mrs	x2, icc_ap1r0_el1
[^:]*:	d518c903 	msr	icc_ap1r0_el1, x3
[^:]*:	d538c922 	mrs	x2, icc_ap1r1_el1
[^:]*:	d518c923 	msr	icc_ap1r1_el1, x3
[^:]*:	d538c942 	mrs	x2, icc_ap1r2_el1
[^:]*:	d518c943 	msr	icc_ap1r2_el1, x3
[^:]*:	d538c962 	mrs	x2, icc_ap1r3_el1
[^:]*:	d518c963 	msr	icc_ap1r3_el1, x3
[^:]*:	d518cb21 	msr	icc_dir_el1, x1
[^:]*:	d538cb60 	mrs	x0, icc_rpr_el1
[^:]*:	d518cba1 	msr	icc_sgi1r_el1, x1
[^:]*:	d518cbc1 	msr	icc_asgi1r_el1, x1
[^:]*:	d518cbe1 	msr	icc_sgi0r_el1, x1
[^:]*:	d538cc00 	mrs	x0, icc_iar1_el1
[^:]*:	d518cc21 	msr	icc_eoir1_el1, x1
[^:]*:	d538cc40 	mrs	x0, icc_hppir1_el1
[^:]*:	d538cc62 	mrs	x2, icc_bpr1_el1
[^:]*:	d518cc63 	msr	icc_bpr1_el1, x3
[^:]*:	d538cc82 	mrs	x2, icc_ctlr_el1
[^:]*:	d518cc83 	msr	icc_ctlr_el1, x3
[^:]*:	d538ccc2 	mrs	x2, icc_igrpen0_el1
[^:]*:	d518ccc3 	msr	icc_igrpen0_el1, x3
[^:]*:	d538cce2 	mrs	x2, icc_igrpen1_el1
[^:]*:	d518cce3 	msr	icc_igrpen1_el1, x3
[^:]*:	d53cc802 	mrs	x2, ich_ap0r0_el2
[^:]*:	d51cc803 	msr	ich_ap0r0_el2, x3
[^:]*:	d53cc822 	mrs	x2, ich_ap0r1_el2
[^:]*:	d51cc823 	msr	ich_ap0r1_el2, x3
[^:]*:	d53cc842 	mrs	x2, ich_ap0r2_el2
[^:]*:	d51cc843 	msr	ich_ap0r2_el2, x3
[^:]*:	d53cc862 	mrs	x2, ich_ap0r3_el2
[^:]*:	d51cc863 	msr	ich_ap0r3_el2, x3
[^:]*:	d53cc902 	mrs	x2, ich_ap1r0_el2
[^:]*:	d51cc903 	msr	ich_ap1r0_el2, x3
[^:]*:	d53cc922 	mrs	x2, ich_ap1r1_el2
[^:]*:	d51cc923 	msr	ich_ap1r1_el2, x3
[^:]*:	d53cc942 	mrs	x2, ich_ap1r2_el2
[^:]*:	d51cc943 	msr	ich_ap1r2_el2, x3
[^:]*:	d53cc962 	mrs	x2, ich_ap1r3_el2
[^:]*:	d51cc963 	msr	ich_ap1r3_el2, x3
[^:]*:	d53ccb02 	mrs	x2, ich_hcr_el2
[^:]*:	d51ccb03 	msr	ich_hcr_el2, x3
[^:]*:	d53ccb40 	mrs	x0, ich_misr_el2
[^:]*:	d53ccb60 	mrs	x0, ich_eisr_el2
[^:]*:	d53ccba0 	mrs	x0, ich_elrsr_el2
[^:]*:	d53ccbe2 	mrs	x2, ich_vmcr_el2
[^:]*:	d51ccbe3 	msr	ich_vmcr_el2, x3
[^:]*:	d53ccc02 	mrs	x2, ich_lr0_el2
[^:]*:	d51ccc03 	msr	ich_lr0_el2, x3
[^:]*:	d53ccc22 	mrs	x2, ich_lr1_el2
[^:]*:	d51ccc23 	msr	ich_lr1_el2, x3
[^:]*:	d53ccc42 	mrs	x2, ich_lr2_el2
[^:]*:	d51ccc43 	msr	ich_lr2_el2, x3
[^:]*:	d53ccc62 	mrs	x2, ich_lr3_el2
[^:]*:	d51ccc63 	msr	ich_lr3_el2, x3
[^:]*:	d53ccc82 	mrs	x2, ich_lr4_el2
[^:]*:	d51ccc83 	msr	ich_lr4_el2, x3
[^:]*:	d53ccca2 	mrs	x2, ich_lr5_el2
[^:]*:	d51ccca3 	msr	ich_lr5_el2, x3
[^:]*:	d53cccc2 	mrs	x2, ich_lr6_el2
[^:]*:	d51cccc3 	msr	ich_lr6_el2, x3
[^:]*:	d53ccce2 	mrs	x2, ich_lr7_el2
[^:]*:	d51ccce3 	msr	ich_lr7_el2, x3
[^:]*:	d53ccd02 	mrs	x2, ich_lr8_el2
[^:]*:	d51ccd03 	msr	ich_lr8_el2, x3
[^:]*:	d53ccd22 	mrs	x2, ich_lr9_el2
[^:]*:	d51ccd23 	msr	ich_lr9_el2, x3
[^:]*:	d53ccd42 	mrs	x2, ich_lr10_el2
[^:]*:	d51ccd43 	msr	ich_lr10_el2, x3
[^:]*:	d53ccd62 	mrs	x2, ich_lr11_el2
[^:]*:	d51ccd63 	msr	ich_lr11_el2, x3
[^:]*:	d53ccd82 	mrs	x2, ich_lr12_el2
[^:]*:	d51ccd83 	msr	ich_lr12_el2, x3
[^:]*:	d53ccda2 	mrs	x2, ich_lr13_el2
[^:]*:	d51ccda3 	msr	ich_lr13_el2, x3
[^:]*:	d53ccdc2 	mrs	x2, ich_lr14_el2
[^:]*:	d51ccdc3 	msr	ich_lr14_el2, x3
[^:]*:	d53ccde2 	mrs	x2, ich_lr15_el2
[^:]*:	d51ccde3 	msr	ich_lr15_el2, x3
[^:]*:	d53ecce2 	mrs	x2, icc_igrpen1_el3
[^:]*:	d51ecce3 	msr	icc_igrpen1_el3, x3
[^:]*:	d538a4e0 	mrs	x0, lorid_el1
[^:]*:	d5390040 	mrs	x0, ccsidr2_el1
[^:]*:	d5381222 	mrs	x2, trfcr_el1
[^:]*:	d5181223 	msr	trfcr_el1, x3
[^:]*:	d5389ec0 	mrs	x0, pmmir_el1
[^:]*:	d53c1222 	mrs	x2, trfcr_el2
[^:]*:	d51c1223 	msr	trfcr_el2, x3
[^:]*:	d53d1222 	mrs	x2, trfcr_el12
[^:]*:	d51d1223 	msr	trfcr_el12, x3
[^:]*:	d53bd202 	mrs	x2, amcr_el0
[^:]*:	d51bd203 	msr	amcr_el0, x3
[^:]*:	d53bd220 	mrs	x0, amcfgr_el0
[^:]*:	d53bd240 	mrs	x0, amcgcr_el0
[^:]*:	d53bd262 	mrs	x2, amuserenr_el0
[^:]*:	d51bd263 	msr	amuserenr_el0, x3
[^:]*:	d53bd282 	mrs	x2, amcntenclr0_el0
[^:]*:	d51bd283 	msr	amcntenclr0_el0, x3
[^:]*:	d53bd2a2 	mrs	x2, amcntenset0_el0
[^:]*:	d51bd2a3 	msr	amcntenset0_el0, x3
[^:]*:	d53bd302 	mrs	x2, amcntenclr1_el0
[^:]*:	d51bd303 	msr	amcntenclr1_el0, x3
[^:]*:	d53bd322 	mrs	x2, amcntenset1_el0
[^:]*:	d51bd323 	msr	amcntenset1_el0, x3
[^:]*:	d53bd402 	mrs	x2, amevcntr00_el0
[^:]*:	d51bd403 	msr	amevcntr00_el0, x3
[^:]*:	d53bd422 	mrs	x2, amevcntr01_el0
[^:]*:	d51bd423 	msr	amevcntr01_el0, x3
[^:]*:	d53bd442 	mrs	x2, amevcntr02_el0
[^:]*:	d51bd443 	msr	amevcntr02_el0, x3
[^:]*:	d53bd462 	mrs	x2, amevcntr03_el0
[^:]*:	d51bd463 	msr	amevcntr03_el0, x3
[^:]*:	d53bd600 	mrs	x0, amevtyper00_el0
[^:]*:	d53bd620 	mrs	x0, amevtyper01_el0
[^:]*:	d53bd640 	mrs	x0, amevtyper02_el0
[^:]*:	d53bd660 	mrs	x0, amevtyper03_el0
[^:]*:	d53bdc02 	mrs	x2, amevcntr10_el0
[^:]*:	d51bdc03 	msr	amevcntr10_el0, x3
[^:]*:	d53bdc22 	mrs	x2, amevcntr11_el0
[^:]*:	d51bdc23 	msr	amevcntr11_el0, x3
[^:]*:	d53bdc42 	mrs	x2, amevcntr12_el0
[^:]*:	d51bdc43 	msr	amevcntr12_el0, x3
[^:]*:	d53bdc62 	mrs	x2, amevcntr13_el0
[^:]*:	d51bdc63 	msr	amevcntr13_el0, x3
[^:]*:	d53bdc82 	mrs	x2, amevcntr14_el0
[^:]*:	d51bdc83 	msr	amevcntr14_el0, x3
[^:]*:	d53bdca2 	mrs	x2, amevcntr15_el0
[^:]*:	d51bdca3 	msr	amevcntr15_el0, x3
[^:]*:	d53bdcc2 	mrs	x2, amevcntr16_el0
[^:]*:	d51bdcc3 	msr	amevcntr16_el0, x3
[^:]*:	d53bdce2 	mrs	x2, amevcntr17_el0
[^:]*:	d51bdce3 	msr	amevcntr17_el0, x3
[^:]*:	d53bdd02 	mrs	x2, amevcntr18_el0
[^:]*:	d51bdd03 	msr	amevcntr18_el0, x3
[^:]*:	d53bdd22 	mrs	x2, amevcntr19_el0
[^:]*:	d51bdd23 	msr	amevcntr19_el0, x3
[^:]*:	d53bdd42 	mrs	x2, amevcntr110_el0
[^:]*:	d51bdd43 	msr	amevcntr110_el0, x3
[^:]*:	d53bdd62 	mrs	x2, amevcntr111_el0
[^:]*:	d51bdd63 	msr	amevcntr111_el0, x3
[^:]*:	d53bdd82 	mrs	x2, amevcntr112_el0
[^:]*:	d51bdd83 	msr	amevcntr112_el0, x3
[^:]*:	d53bdda2 	mrs	x2, amevcntr113_el0
[^:]*:	d51bdda3 	msr	amevcntr113_el0, x3
[^:]*:	d53bddc2 	mrs	x2, amevcntr114_el0
[^:]*:	d51bddc3 	msr	amevcntr114_el0, x3
[^:]*:	d53bdde2 	mrs	x2, amevcntr115_el0
[^:]*:	d51bdde3 	msr	amevcntr115_el0, x3
[^:]*:	d53bde02 	mrs	x2, amevtyper10_el0
[^:]*:	d51bde03 	msr	amevtyper10_el0, x3
[^:]*:	d53bde22 	mrs	x2, amevtyper11_el0
[^:]*:	d51bde23 	msr	amevtyper11_el0, x3
[^:]*:	d53bde42 	mrs	x2, amevtyper12_el0
[^:]*:	d51bde43 	msr	amevtyper12_el0, x3
[^:]*:	d53bde62 	mrs	x2, amevtyper13_el0
[^:]*:	d51bde63 	msr	amevtyper13_el0, x3
[^:]*:	d53bde82 	mrs	x2, amevtyper14_el0
[^:]*:	d51bde83 	msr	amevtyper14_el0, x3
[^:]*:	d53bdea2 	mrs	x2, amevtyper15_el0
[^:]*:	d51bdea3 	msr	amevtyper15_el0, x3
[^:]*:	d53bdec2 	mrs	x2, amevtyper16_el0
[^:]*:	d51bdec3 	msr	amevtyper16_el0, x3
[^:]*:	d53bdee2 	mrs	x2, amevtyper17_el0
[^:]*:	d51bdee3 	msr	amevtyper17_el0, x3
[^:]*:	d53bdf02 	mrs	x2, amevtyper18_el0
[^:]*:	d51bdf03 	msr	amevtyper18_el0, x3
[^:]*:	d53bdf22 	mrs	x2, amevtyper19_el0
[^:]*:	d51bdf23 	msr	amevtyper19_el0, x3
[^:]*:	d53bdf42 	mrs	x2, amevtyper110_el0
[^:]*:	d51bdf43 	msr	amevtyper110_el0, x3
[^:]*:	d53bdf62 	mrs	x2, amevtyper111_el0
[^:]*:	d51bdf63 	msr	amevtyper111_el0, x3
[^:]*:	d53bdf82 	mrs	x2, amevtyper112_el0
[^:]*:	d51bdf83 	msr	amevtyper112_el0, x3
[^:]*:	d53bdfa2 	mrs	x2, amevtyper113_el0
[^:]*:	d51bdfa3 	msr	amevtyper113_el0, x3
[^:]*:	d53bdfc2 	mrs	x2, amevtyper114_el0
[^:]*:	d51bdfc3 	msr	amevtyper114_el0, x3
[^:]*:	d53bdfe2 	mrs	x2, amevtyper115_el0
[^:]*:	d51bdfe3 	msr	amevtyper115_el0, x3
[^:]*:	d53bd2c0 	mrs	x0, amcg1idr_el0
[^:]*:	d53be0a0 	mrs	x0, cntpctss_el0
[^:]*:	d53be0c0 	mrs	x0, cntvctss_el0
[^:]*:	d53c1182 	mrs	x2, hfgrtr_el2
[^:]*:	d51c1183 	msr	hfgrtr_el2, x3
[^:]*:	d53c11a2 	mrs	x2, hfgwtr_el2
[^:]*:	d51c11a3 	msr	hfgwtr_el2, x3
[^:]*:	d53c11c2 	mrs	x2, hfgitr_el2
[^:]*:	d51c11c3 	msr	hfgitr_el2, x3
[^:]*:	d53c3182 	mrs	x2, hdfgrtr_el2
[^:]*:	d51c3183 	msr	hdfgrtr_el2, x3
[^:]*:	d53c31a2 	mrs	x2, hdfgwtr_el2
[^:]*:	d51c31a3 	msr	hdfgwtr_el2, x3
[^:]*:	d53c31c2 	mrs	x2, hafgrtr_el2
[^:]*:	d51c31c3 	msr	hafgrtr_el2, x3
[^:]*:	d53cd802 	mrs	x2, amevcntvoff00_el2
[^:]*:	d51cd803 	msr	amevcntvoff00_el2, x3
[^:]*:	d53cd822 	mrs	x2, amevcntvoff01_el2
[^:]*:	d51cd823 	msr	amevcntvoff01_el2, x3
[^:]*:	d53cd842 	mrs	x2, amevcntvoff02_el2
[^:]*:	d51cd843 	msr	amevcntvoff02_el2, x3
[^:]*:	d53cd862 	mrs	x2, amevcntvoff03_el2
[^:]*:	d51cd863 	msr	amevcntvoff03_el2, x3
[^:]*:	d53cd882 	mrs	x2, amevcntvoff04_el2
[^:]*:	d51cd883 	msr	amevcntvoff04_el2, x3
[^:]*:	d53cd8a2 	mrs	x2, amevcntvoff05_el2
[^:]*:	d51cd8a3 	msr	amevcntvoff05_el2, x3
[^:]*:	d53cd8c2 	mrs	x2, amevcntvoff06_el2
[^:]*:	d51cd8c3 	msr	amevcntvoff06_el2, x3
[^:]*:	d53cd8e2 	mrs	x2, amevcntvoff07_el2
[^:]*:	d51cd8e3 	msr	amevcntvoff07_el2, x3
[^:]*:	d53cd902 	mrs	x2, amevcntvoff08_el2
[^:]*:	d51cd903 	msr	amevcntvoff08_el2, x3
[^:]*:	d53cd922 	mrs	x2, amevcntvoff09_el2
[^:]*:	d51cd923 	msr	amevcntvoff09_el2, x3
[^:]*:	d53cd942 	mrs	x2, amevcntvoff010_el2
[^:]*:	d51cd943 	msr	amevcntvoff010_el2, x3
[^:]*:	d53cd962 	mrs	x2, amevcntvoff011_el2
[^:]*:	d51cd963 	msr	amevcntvoff011_el2, x3
[^:]*:	d53cd982 	mrs	x2, amevcntvoff012_el2
[^:]*:	d51cd983 	msr	amevcntvoff012_el2, x3
[^:]*:	d53cd9a2 	mrs	x2, amevcntvoff013_el2
[^:]*:	d51cd9a3 	msr	amevcntvoff013_el2, x3
[^:]*:	d53cd9c2 	mrs	x2, amevcntvoff014_el2
[^:]*:	d51cd9c3 	msr	amevcntvoff014_el2, x3
[^:]*:	d53cd9e2 	mrs	x2, amevcntvoff015_el2
[^:]*:	d51cd9e3 	msr	amevcntvoff015_el2, x3
[^:]*:	d53cda02 	mrs	x2, amevcntvoff10_el2
[^:]*:	d51cda03 	msr	amevcntvoff10_el2, x3
[^:]*:	d53cda22 	mrs	x2, amevcntvoff11_el2
[^:]*:	d51cda23 	msr	amevcntvoff11_el2, x3
[^:]*:	d53cda42 	mrs	x2, amevcntvoff12_el2
[^:]*:	d51cda43 	msr	amevcntvoff12_el2, x3
[^:]*:	d53cda62 	mrs	x2, amevcntvoff13_el2
[^:]*:	d51cda63 	msr	amevcntvoff13_el2, x3
[^:]*:	d53cda82 	mrs	x2, amevcntvoff14_el2
[^:]*:	d51cda83 	msr	amevcntvoff14_el2, x3
[^:]*:	d53cdaa2 	mrs	x2, amevcntvoff15_el2
[^:]*:	d51cdaa3 	msr	amevcntvoff15_el2, x3
[^:]*:	d53cdac2 	mrs	x2, amevcntvoff16_el2
[^:]*:	d51cdac3 	msr	amevcntvoff16_el2, x3
[^:]*:	d53cdae2 	mrs	x2, amevcntvoff17_el2
[^:]*:	d51cdae3 	msr	amevcntvoff17_el2, x3
[^:]*:	d53cdb02 	mrs	x2, amevcntvoff18_el2
[^:]*:	d51cdb03 	msr	amevcntvoff18_el2, x3
[^:]*:	d53cdb22 	mrs	x2, amevcntvoff19_el2
[^:]*:	d51cdb23 	msr	amevcntvoff19_el2, x3
[^:]*:	d53cdb42 	mrs	x2, amevcntvoff110_el2
[^:]*:	d51cdb43 	msr	amevcntvoff110_el2, x3
[^:]*:	d53cdb62 	mrs	x2, amevcntvoff111_el2
[^:]*:	d51cdb63 	msr	amevcntvoff111_el2, x3
[^:]*:	d53cdb82 	mrs	x2, amevcntvoff112_el2
[^:]*:	d51cdb83 	msr	amevcntvoff112_el2, x3
[^:]*:	d53cdba2 	mrs	x2, amevcntvoff113_el2
[^:]*:	d51cdba3 	msr	amevcntvoff113_el2, x3
[^:]*:	d53cdbc2 	mrs	x2, amevcntvoff114_el2
[^:]*:	d51cdbc3 	msr	amevcntvoff114_el2, x3
[^:]*:	d53cdbe2 	mrs	x2, amevcntvoff115_el2
[^:]*:	d51cdbe3 	msr	amevcntvoff115_el2, x3
[^:]*:	d53ce0c2 	mrs	x2, cntpoff_el2
[^:]*:	d51ce0c3 	msr	cntpoff_el2, x3
[^:]*:	d5389922 	mrs	x2, pmsnevfr_el1
[^:]*:	d5189923 	msr	pmsnevfr_el1, x3
[^:]*:	d53c1242 	mrs	x2, hcrx_el2
[^:]*:	d51c1243 	msr	hcrx_el2, x3
