.*: Assembler messages:
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcauthstatus,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trccidr0,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trccidr1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trccidr2,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trccidr3,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcdevaff0,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcdevaff1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcdevarch,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcdevid,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcdevtype,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr0,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr2,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr3,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr4,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr5,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr6,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr7,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr8,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr9,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr10,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr11,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr12,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcidr13,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trclsr,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcoslsr,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcpdsr,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcpidr0,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcpidr1,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcpidr2,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcpidr3,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcpidr4,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcpidr5,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcpidr6,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcpidr7,x0'
.*: Warning: specified register cannot be written to at operand 1 -- `msr trcstatr,x0'
