.*: Assembler messages:
.*: Error: selected processor does not support system register name 'lorid_el1'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'ccsidr2_el1'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'trfcr_el1'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'trfcr_el1'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'pmmir_el1'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'trfcr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'trfcr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'trfcr_el12'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'trfcr_el12'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcr_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcr_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcfgr_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcgcr_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amuserenr_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amuserenr_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcntenclr0_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcntenclr0_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcntenset0_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcntenset0_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcntenclr1_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcntenclr1_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcntenset1_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcntenset1_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr00_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr00_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr01_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr01_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr02_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr02_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr03_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr03_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper00_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper01_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper02_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper03_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr10_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr10_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr11_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr11_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr12_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr12_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr13_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr13_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr14_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr14_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr15_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr15_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr16_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr16_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr17_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr17_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr18_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr18_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr19_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr19_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr110_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr110_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr111_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr111_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr112_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr112_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr113_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr113_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr114_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr114_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr115_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntr115_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper10_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper10_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper11_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper11_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper12_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper12_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper13_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper13_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper14_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper14_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper15_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper15_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper16_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper16_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper17_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper17_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper18_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper18_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper19_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper19_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper110_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper110_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper111_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper111_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper112_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper112_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper113_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper113_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper114_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper114_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper115_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevtyper115_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amcg1idr_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'cntpctss_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'cntvctss_el0'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hfgrtr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hfgrtr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hfgwtr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hfgwtr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hfgitr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hfgitr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hdfgrtr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hdfgrtr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hdfgwtr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hdfgwtr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hafgrtr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hafgrtr_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff00_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff00_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff01_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff01_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff02_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff02_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff03_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff03_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff04_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff04_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff05_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff05_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff06_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff06_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff07_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff07_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff08_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff08_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff09_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff09_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff010_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff010_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff011_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff011_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff012_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff012_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff013_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff013_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff014_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff014_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff015_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff015_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff10_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff10_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff11_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff11_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff12_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff12_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff13_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff13_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff14_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff14_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff15_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff15_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff16_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff16_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff17_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff17_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff18_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff18_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff19_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff19_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff110_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff110_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff111_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff111_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff112_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff112_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff113_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff113_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff114_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff114_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff115_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'amevcntvoff115_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'cntpoff_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'cntpoff_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'pmsnevfr_el1'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'pmsnevfr_el1'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hcrx_el2'
.*: *Info: macro .*
.*: Error: selected processor does not support system register name 'hcrx_el2'
.*: *Info: macro .*
