[^:]*: Assembler messages:
[^:]*:6: Error: cannot honor width suffix -- `add.n r4,#8'
[^:]*:9: Error: cannot honor width suffix -- `sub.n r4,#8'
[^:]*:12: Error: cannot honor width suffix -- `lsl.n r4,#8'
[^:]*:13: Error: cannot honor width suffix -- `lsl.n sp,#8'
#pass
