.*Assembler messages:
.*: Error: unrecognized opcode `mul a0,a1,a2', extension `m' or `zmmul' required
.*: Error: unrecognized opcode `mulh a0,a1,a2', extension `m' or `zmmul' required
.*: Error: unrecognized opcode `mulhsu a0,a1,a2', extension `m' or `zmmul' required
.*: Error: unrecognized opcode `mulhu a0,a1,a2', extension `m' or `zmmul' required
.*: Error: unrecognized opcode `div a0,a1,a2', extension `m' required
.*: Error: unrecognized opcode `divu a0,a1,a2', extension `m' required
.*: Error: unrecognized opcode `rem a0,a1,a2', extension `m' required
.*: Error: unrecognized opcode `remu a0,a1,a2', extension `m' required
.*: Error: unrecognized opcode `mulw a0,a1,a2', extension `m' or `zmmul' required
.*: Error: unrecognized opcode `divw a0,a1,a2', extension `m' required
.*: Error: unrecognized opcode `divuw a0,a1,a2', extension `m' required
.*: Error: unrecognized opcode `remw a0,a1,a2', extension `m' required
.*: Error: unrecognized opcode `remuw a0,a1,a2', extension `m' required
